Discover Packages
github.com/mohammedbalila/yusra
cmd
package
Version:
v0.0.0-...-4115b63
Opens a new window with list of versions in this module.
Published: Jun 1, 2024
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
Copyright © 2024 NAME HERE <EMAIL ADDRESS>
Execute adds all child commands to the root command and sets flags appropriately.
This is called by main.main(). It only needs to happen once to the rootCmd.
type Result []interface{}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.